@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,18 +68,34 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "CHF", "CHF" },
+            { "DKK", "DKK" },
+            { "EEK", "EEK" },
+            { "FIM", "FIM" },
+            { "HNL", "HNL" },
+            { "IEP", "IEP" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "KYD", "KYD" },
+            { "NOK", "NOK" },
+            { "PLN", "PLN" },
+            { "RUB", "RUB" },
+            { "RUR", "RUR" },
+            { "SAR", "SAR" },
+            { "SEK", "SEK" },
+            { "TRY", "TRY" },
+            { "USD", "$" },
             { "adp", "peseta andorrana" },
             { "aed", "dirham dals Emirats Arabs Unids" },
-            { "afa", "afghani (1927\u20132002)" },
-            { "afn", "afghani" },
+            { "afa", "afgani afgan (1927\u20132002)" },
+            { "afn", "afgani afgan" },
             { "alk", "lek albanais (1947\u20131961)" },
-            { "all", "lek" },
+            { "all", "lek albanais" },
             { "amd", "dram armen" },
-            { "ang", "flurin da las Antillas Olandaisas" },
+            { "ang", "flurin da las Antillas Ollandaisas" },
             { "aoa", "kwanza angolan" },
-            { "aok", "kwanza angolan (1977\u20131990)" },
-            { "aon", "nov kwanza angolan" },
-            { "aor", "kwanza angolan reajustado" },
+            { "aok", "kwanza angolan (1977\u20131991)" },
+            { "aon", "nov kwanza angolan (1990\u20132000)" },
+            { "aor", "kwanza angolan reagiust\u00e0 (1995\u20131999)" },
             { "ara", "austral argentin" },
             { "arl", "peso argentin ley" },
             { "arm", "peso argentin moneda nacional" },
@@ -92,25 +104,25 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "ats", "schilling austriac" },
             { "aud", "dollar australian" },
             { "awg", "flurin da l\u2019Aruba" },
-            { "azm", "manat aserbaidschanic (1993\u20132006)" },
-            { "azn", "manat aserbaidschanic" },
-            { "bad", "dinar da la Bosnia ed Erzegovina" },
-            { "bam", "marc convertibel bosniac" },
-            { "ban", "nov dinar da la Bosnia ed Erzegovina" },
+            { "azm", "manat aserbaidschan (1993\u20132006)" },
+            { "azn", "manat aserbaidschan" },
+            { "bad", "dinar da la Bosnia-Erzegovina (1992\u20131994)" },
+            { "bam", "marc convertibel da la Bosnia-Erzegovina" },
+            { "ban", "nov dinar da la Bosnia-Erzegovina (1994\u20131997)" },
             { "bbd", "dollar da Barbados" },
             { "bdt", "taka bangladais" },
             { "bec", "franc beltg (convertibel)" },
             { "bef", "franc beltg" },
             { "bel", "franc beltg (finanzial)" },
-            { "bgl", "lev bulgar" },
+            { "bgl", "lev bulgar dir" },
             { "bgm", "lev bulgar socialistic" },
-            { "bgn", "nov lev bulgar" },
-            { "bgo", "vegl lev bulgar" },
+            { "bgn", "lev bulgar" },
+            { "bgo", "lev bulgar (1879\u20131952)" },
             { "bhd", "dinar dal Bahrain" },
             { "bif", "franc dal Burundi" },
             { "bmd", "dollar da las Bermudas" },
             { "bnd", "dollar dal Brunei" },
-            { "bob", "boliviano" },
+            { "bob", "boliviano bolivian" },
             { "bol", "vegl boliviano" },
             { "bop", "peso bolivian" },
             { "bov", "mvdol bolivian" },
@@ -123,9 +135,9 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "brz", "vegl cruzeiro brasilian" },
             { "bsd", "dollar da las Bahamas" },
             { "btn", "ngultrum butanais" },
-            { "buk", "Kyat burmais" },
+            { "buk", "kyat burmais" },
             { "bwp", "pula da la Botswana" },
-            { "byb", "nov rubel bieloruss (1994\u20131999)" },
+            { "byb", "rubel bieloruss (1994\u20131999)" },
             { "byn", "rubel bieloruss" },
             { "byr", "rubel bieloruss (2000\u20132016)" },
             { "bzd", "dollar dal Belize" },
@@ -137,12 +149,14 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "cle", "escudo chilen" },
             { "clf", "unidades de fomento chilenas" },
             { "clp", "peso chilen" },
-            { "cny", "yuan renminbi chinais" },
+            { "cnh", "yuan chinais (offshore)" },
+            { "cny", "yuan chinais" },
             { "cop", "peso columbian" },
             { "cou", "unidad de valor real" },
             { "crc", "colon da la Costa Rica" },
-            { "csd", "vegl dinar serb" },
+            { "csd", "dinar serb (2002\u20132006)" },
             { "csk", "cruna tschecoslovaca" },
+            { "cuc", "peso cuban convertibel" },
             { "cup", "peso cuban" },
             { "cve", "escudo dal Cap Verd" },
             { "cyp", "glivra cipriota" },
@@ -167,7 +181,7 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "fjd", "dollar dal Fidschi" },
             { "fkp", "glivra dal Falkland" },
             { "frf", "franc franzos" },
-            { "gbp", "glivra sterlina" },
+            { "gbp", "glivra britannica" },
             { "gek", "kupon larit georgian" },
             { "gel", "lari georgian" },
             { "ghc", "cedi ghanais (1979\u20132007)" },
@@ -191,8 +205,8 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "idr", "rupia indonaisa" },
             { "iep", "glivra indonaisa" },
             { "ilp", "glivra israeliana" },
-            { "ilr", "vegl sheqel israelian" },
-            { "ils", "sheqel" },
+            { "ilr", "schekel israelian (1980\u20131985)" },
+            { "ils", "nov schekel israelian" },
             { "inr", "rupia indica" },
             { "iqd", "dinar iracais" },
             { "irr", "rial iranais" },
@@ -203,16 +217,16 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "jod", "dinar jordanic" },
             { "jpy", "yen giapunais" },
             { "kes", "schilling kenian" },
-            { "kgs", "som kirghis" },
+            { "kgs", "som kirgis" },
             { "khr", "riel cambodschan" },
             { "kmf", "franc comorian" },
             { "kpw", "won da la Corea dal Nord" },
-            { "krh", "hwan da la Corea dal Sid" },
-            { "kro", "vegl won da la Corea dal Sid" },
+            { "krh", "hwan da la Corea dal Sid (1953\u20131962)" },
+            { "kro", "won da la Corea dal Sid (1945\u20131953)" },
             { "krw", "won da la Corea dal Sid" },
             { "kwd", "dinar dal Kuwait" },
             { "kyd", "dollar da las Inslas Cayman" },
-            { "kzt", "tenge casac" },
+            { "kzt", "tenge kasac" },
             { "lak", "kip laot" },
             { "lbp", "glivra libanaisa" },
             { "lkr", "rupia da la Sri Lanka" },
@@ -228,15 +242,15 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "lyd", "dinar libic" },
             { "mad", "dirham marocan" },
             { "maf", "franc marocan" },
-            { "mcf", "franc monegas" },
+            { "mcf", "franc monegass" },
             { "mdc", "cupon moldav" },
             { "mdl", "leu moldav" },
             { "mga", "ariary madagasc" },
             { "mgf", "franc madagasc" },
-            { "mkd", "dinar da la Macedonia" },
-            { "mkn", "vegl dinar macedon" },
+            { "mkd", "dinar macedon" },
+            { "mkn", "dinar macedon (1992\u20131993)" },
             { "mlf", "franc dal Mali" },
-            { "mmk", "Kyat dal Myanmar" },
+            { "mmk", "kyat dal Myanmar" },
             { "mnt", "tugrik mongolic" },
             { "mop", "pataca dal Macao" },
             { "mro", "ouguiya da la Mauretania (1973\u20132017)" },
@@ -244,20 +258,20 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "mtl", "lira maltaisa" },
             { "mtp", "glivra maltaisa" },
             { "mur", "rupia dal Mauritius" },
-            { "mvp", "rupia da las Maledivas" },
+            { "mvp", "rupia da las Maledivas (1947\u20131981)" },
             { "mvr", "rufiyaa da las Maledivas" },
             { "mwk", "kwacha dal Malawi" },
             { "mxn", "peso mexican" },
             { "mxp", "peso d\u2019argient mexican (1861\u20131992)" },
             { "mxv", "unidad de inversion mexicana (UDI)" },
-            { "myr", "ringgit da la Malaisia" },
-            { "mze", "escudo dal mozambican" },
-            { "mzm", "vegl metical mozambican" },
-            { "mzn", "metical dal mozambican" },
+            { "myr", "ringgit malaisic" },
+            { "mze", "escudo dal Mosambic" },
+            { "mzm", "metical dal Mosambic (1980\u20132006)" },
+            { "mzn", "metical dal Mosambic" },
             { "nad", "dollar namibian" },
             { "ngn", "naira nigeriana" },
             { "nic", "cordoba nicaraguan" },
-            { "nio", "cordoba oro nicaraguan" },
+            { "nio", "c\u00f3rdoba nicaraguan" },
             { "nlg", "flurin ollandais" },
             { "nok", "cruna norvegiaisa" },
             { "npr", "rupia nepalaisa" },
@@ -274,20 +288,20 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "plz", "zloty polac (1950\u20131995)" },
             { "pte", "escudo portugais" },
             { "pyg", "guarani paraguaian" },
-            { "qar", "riyal da Katar" },
+            { "qar", "rial da Katar" },
             { "rhd", "dollar rodesian" },
-            { "rol", "vegl leu rumen" },
+            { "rol", "leu rumen (1952\u20132006)" },
             { "ron", "leu rumen" },
             { "rsd", "dinar serb" },
-            { "rub", "rubel russ (nov)" },
+            { "rub", "rubel russ" },
             { "rur", "rubel russ (vegl)" },
             { "rwf", "franc ruandais" },
             { "sar", "riyal saudit" },
-            { "sbd", "dollar da las Salomonas" },
+            { "sbd", "dollar da las Inslas da Salomon" },
             { "scr", "rupia da las Seychellas" },
-            { "sdd", "dinar sudanais" },
+            { "sdd", "dinar sudanais (1992\u20132007)" },
             { "sdg", "glivra sudanaisa" },
-            { "sdp", "glivra sudanaisa (1956\u20132007)" },
+            { "sdp", "glivra sudanaisa (1957\u20131998)" },
             { "sek", "cruna svedaisa" },
             { "sgd", "dollar dal Singapur" },
             { "shp", "glivra da Sontg\u2019Elena" },
@@ -297,6 +311,7 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "sos", "schilling somalian" },
             { "srd", "dollar surinam" },
             { "srg", "flurin surinam" },
+            { "ssp", "glivra sidsudanaisa" },
             { "std", "dobra da S\u00e3o Tom\u00e9 e Principe (1977\u20132017)" },
             { "stn", "dobra da S\u00e3o Tom\u00e9 e Principe" },
             { "sur", "rubel sovietic" },
@@ -304,36 +319,37 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "syp", "glivra siriana" },
             { "szl", "lilangeni dal Swaziland" },
             { "thb", "baht tailandais" },
-            { "tjr", "rubel dal Tadschikistan" },
-            { "tjs", "somoni dal Tadschikistan" },
-            { "tmm", "manat turkmen" },
+            { "tjr", "rubel tadschic" },
+            { "tjs", "somoni tadschic" },
+            { "tmm", "manat turkmen (1993\u20132009)" },
+            { "tmt", "manat turkmen" },
             { "tnd", "dinar tunesian" },
-            { "top", "pa\u2019anga da Tonga" },
-            { "tpe", "escudo da Timor" },
-            { "trl", "lira tirca" },
-            { "try", "nova lira tirca" },
+            { "top", "pa\u02bbanga da Tonga" },
+            { "tpe", "escudo dal Timor" },
+            { "trl", "lira tirca (1922\u20132005)" },
+            { "try", "lira tirca" },
             { "ttd", "dollar da Trinidad e Tobago" },
             { "twd", "nov dollar taiwanais" },
             { "tzs", "schilling tansanian" },
-            { "uah", "hryvnia ucranais" },
-            { "uak", "karbovanetz ucranais" },
-            { "ugs", "schilling ucranais" },
+            { "uah", "hryvnia ucranaisa" },
+            { "uak", "karbovanets ucranais" },
+            { "ugs", "schilling ugandais (1966\u20131987)" },
             { "ugx", "schilling ugandais" },
-            { "usd", "dollar dals Stadis Unids da l\u2019America" },
+            { "usd", "dollar da l\u2019USA" },
             { "usn", "dollar dals Stadis Unids da l\u2019America (proxim di)" },
             { "uss", "dollar dals Stadis Unids da l\u2019America (medem di)" },
             { "uyi", "peso da l\u2019Uruguay (unidades indexadas)" },
             { "uyp", "nov peso da l\u2019Uruguay (1975\u20131993)" },
             { "uyu", "peso da l\u2019Uruguay" },
-            { "uzs", "sum usbec" },
+            { "uzs", "som usbec" },
             { "veb", "bolivar venezuelan (1871\u20132008)" },
             { "vef", "bolivar venezuelan (2008\u20132018)" },
-            { "ves", "bolivar venezuelan" },
+            { "ves", "bol\u00edvar venezuelan" },
             { "vnd", "dong vietnamais" },
-            { "vnn", "vegl dong vietnamais" },
+            { "vnn", "dong vietnamais (1978\u20131985)" },
             { "vuv", "vatu dal Vanuatu" },
             { "wst", "tala da la Samoa" },
-            { "xaf", "franc CFA BEAC" },
+            { "xaf", "franc CFA da l\u2019Africa Centrala" },
             { "xag", "argient" },
             { "xau", "aur" },
             { "xba", "unitad europeica cumponida" },
@@ -343,26 +359,28 @@ public class CurrencyNames_rm extends OpenListResourceBundle {
             { "xdr", "dretgs da prelevaziun spezials" },
             { "xfo", "franc d\u2019aur franzos" },
             { "xfu", "franc UIC franzos" },
-            { "xof", "franc CFA BCEAO" },
+            { "xof", "franc CFA da l\u2019Africa dal Vest" },
             { "xpd", "palladi" },
             { "xpf", "franc CFP" },
             { "xpt", "platin" },
             { "xre", "fonds RINET" },
             { "xts", "code per verifitgar la valuta" },
             { "xxx", "valuta nunenconuschenta" },
-            { "ydd", "dinar dal Jemen" },
-            { "yer", "rial dal Jemen" },
-            { "yud", "dinar jugoslav (1966\u20131990)" },
-            { "yum", "nov dinar jugoslav" },
-            { "yun", "dinar jugoslav convertibel" },
-            { "yur", "dinar jugoslav refurm\u00e0" },
+            { "ydd", "dinar jemenit" },
+            { "yer", "rial jemenit" },
+            { "yud", "dinar jugoslav dir (1966\u20131990)" },
+            { "yum", "nov dinar jugoslav (1994\u20132002)" },
+            { "yun", "dinar jugoslav convertibel (1990\u20131992)" },
+            { "yur", "dinar jugoslav refurm\u00e0 (1992\u20131993)" },
             { "zal", "rand sidafrican (finanzial)" },
             { "zar", "rand sidafrican" },
-            { "zmk", "kwacha da la sambia (1968\u20132012)" },
+            { "zmk", "kwacha da la Sambia (1968\u20132012)" },
             { "zmw", "kwacha da la sambia" },
-            { "zrn", "nov zaire dal Zaire" },
+            { "zrn", "nov zaire dal Zaire (1993\u20131998)" },
             { "zrz", "zaire dal Zaire" },
-            { "zwd", "dollar dal Simbabwe" },
+            { "zwd", "dollar dal Simbabwe (1980\u20132008)" },
+            { "zwl", "dollar dal Simbabwe (2009)" },
+            { "zwr", "dollar dal Simbabwe (2008)" },
         };
         return data;
     }
